Example dataset representing the ATC tree structure, sourced from the WHO website (2024-02-23). This dataset is provided for demonstration and testing purposes with the package.
ATC_Tree_UpperBound_2024A data frame with 4 variables:
The code of ATC nodes
The name of ATC nodes
The number of characters in the ATCCode
The index of the last child node in the tree