Learn R Programming

emcAdr (version 1.2)

get_dissimilarity_from_txt_file: Recover the square matrix of distance between cocktails where the index (i,j) of the matrix is the distance between cocktails i and j in the csv file containing results of genetic algorithm

Description

Recover the square matrix of distance between cocktails where the index (i,j) of the matrix is the distance between cocktails i and j in the csv file containing results of genetic algorithm

Usage

get_dissimilarity_from_txt_file(filename, ATCtree, normalization = TRUE)

Value

The square matrix of distances between cocktails

Arguments

filename

: the name of the file returned by the print_csv function.

ATCtree

: ATC tree with upper bound of the DFS (without the root)

normalization

: Do we keep the distance between cocktail in the range [0;1] ?

Examples

Run this code
# \donttest{
 data("ATC_Tree_UpperBound_2024")
 
 distance_matrix = get_dissimilarity_from_txt_file(filename = '250e_700ind_0.2mr_0ne_2alpha.txt',
                        ATCtree = ATC_Tree_UpperBound_2024, normalization = TRUE)
# }

Run the code above in your browser using DataLab