Learn R Programming

emcAdr (version 1.2)

int_cocktail_to_string_cocktail: Function used to convert integer cocktails (like the one outputed by the distributionApproximation function) to string cocktail in order to make them more readable

Description

Function used to convert integer cocktails (like the one outputed by the distributionApproximation function) to string cocktail in order to make them more readable

Usage

int_cocktail_to_string_cocktail(cocktails, ATC_name)

Value

The name of integer cocktails in cocktails

Arguments

cocktails

cocktails vector to be converted (index in the ATC tree)

ATC_name

The ATC_name column of the ATC tree

Examples

Run this code
# \donttest{
  data("ATC_Tree_UpperBound_2024")
  int_list = list(c(561, 904),
               c(1902, 4585))
  int_cocktail_to_string_cocktail(int_list, ATC_Tree_UpperBound_2024$Name)
# }

Run the code above in your browser using DataLab