Example dataset representing drug intake and adverse event reports from FAERS.
This dataset is provided to demonstrate the functionality of genetic and MCMC algorithms in the package.
Usage
FAERS_myopathy
Arguments
Format
A data frame with 2 columns:
patientATC
Drug intake for each patient as a vector of ATC tree indices
patientADR
Indicates if the patient experienced myopathy as an adverse event