int_cocktail_to_string_cocktail: Function used to convert integer cocktails (like the one outputed by the distributionApproximation function)
to string cocktail in order to make them more readable
Description
Function used to convert integer cocktails (like the one outputed by the distributionApproximation function)
to string cocktail in order to make them more readable